@@ -4,7 +4,7 @@ any .pack files the frostwire installation folder. It'll unpack them and then
 it'll update the hashes file, so that frostwire can start.
 '''
 import os
-INSTDIR='/usr/lib/frostwire'    
+INSTDIR='/usr/share/frostwire'    
 def makeHashes():
   #creates the hashes based on the md5s of all the jars
   import md5
